Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java')
-rw-r--r--extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java123
1 files changed, 20 insertions, 103 deletions
diff --git a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java
index 3502e75f6ef..de2589c132b 100644
--- a/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java
+++ b/extraplugins/eastadl/org.eclipse.papyrus.eastadl/src/org/eclipse/papyrus/eastadl/timing/PrecedenceConstraint.java
@@ -16,143 +16,60 @@
package org.eclipse.papyrus.eastadl.timing;
import org.eclipse.emf.common.util.EList;
-import org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype;
-import org.eclipse.uml2.uml.Dependency;
+import org.eclipse.papyrus.eastadl.infrastructure.PrecedenceConstraint_precedingInstanceRef;
+import org.eclipse.papyrus.eastadl.infrastructure.PrecedenceConstraint_successiveInstanceRef;
/**
* <!-- begin-user-doc -->
* A representation of the model object '<em><b>Precedence Constraint</b></em>'.
* <!-- end-user-doc -->
- *
- * <!-- begin-model-doc -->
- * The PrecedenceConstraint represents a particular constraint applied on the execution sequence of functions.
- *
- * Semantics:
- * The semantics for the PrecedenceConstraint metaclass is to define an association relationship between Functions, indicating the association
- * relationship such that all predecessors have completed before the successors are started.
- *
- * Note: Without a precedence relation, Functions are executed according to their data dependencies, if these are uni-directional. For bi-directional
- * data dependencies, execution order is not defined unless the PrecedenceDependency relationship is used.
- *
- * Notation:
- * PrecedenceConstraint is shown as a dashed arrow with "Precedes" next to it. It points from preceeding to the successive entity.
- *
- * Changes:
- * Renamed from Precedes
- *
- * Extension:
- * The PrecedenceConstraint extends UML2 metaclass Class and Dependency.
- * <!-- end-model-doc -->
- *
+ *
* <p>
* The following features are supported:
* <ul>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getSuccessive <em>Successive</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getPreceding <em>Preceding</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getBase_Dependency <em>Base Dependency</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getSuccessive_path <em>Successive path</em>}</li>
- * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getPreceding_path <em>Preceding path</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getPreceding <em>Preceding</em>}</li>
+ * <li>{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getSuccessive <em>Successive</em>}</li>
* </ul>
* </p>
- *
+ *
* @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint()
* @model
* @generated
*/
public interface PrecedenceConstraint extends TimingConstraint {
-
/**
- * Returns the value of the '<em><b>Preceding</b></em>' reference.
+ * Returns the value of the '<em><b>Preceding</b></em>' containment reference.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * <!-- begin-model-doc -->
- * The function prototype that must be executed first.
- * {derived from UML::DirectedRelationship::source}
- * <!-- end-model-doc -->
- *
- * @return the value of the '<em>Preceding</em>' reference.
+ * @return the value of the '<em>Preceding</em>' containment reference.
+ * @see #setPreceding(PrecedenceConstraint_precedingInstanceRef)
* @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint_Preceding()
- * @model required="true" transient="true" changeable="false" volatile="true" derived="true" ordered="false"
- * @generated
- */
- FunctionPrototype getPreceding();
-
- /**
- * Returns the value of the '<em><b>Base Dependency</b></em>' reference.
- * <!-- begin-user-doc -->
- * <p>
- * If the meaning of the '<em>Base Dependency</em>' reference isn't clear, there really should be more of a description here...
- * </p>
- * <!-- end-user-doc -->
- *
- * @return the value of the '<em>Base Dependency</em>' reference.
- * @see #setBase_Dependency(Dependency)
- * @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint_Base_Dependency()
- * @model ordered="false"
- * @generated
- */
- Dependency getBase_Dependency();
-
- /**
- * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getBase_Dependency <em>Base Dependency</em>}' reference.
- * <!-- begin-user-doc -->
- * <!-- end-user-doc -->
- *
- * @param value
- * the new value of the '<em>Base Dependency</em>' reference.
- * @see #getBase_Dependency()
- * @generated
- */
- void setBase_Dependency(Dependency value);
-
- /**
- * Returns the value of the '<em><b>Successive path</b></em>' reference list.
- * The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
- * <!-- begin-user-doc -->
- * <p>
- * If the meaning of the '<em>Successive path</em>' reference list isn't clear, there really should be more of a description here...
- * </p>
- * <!-- end-user-doc -->
- *
- * @return the value of the '<em>Successive path</em>' reference list.
- * @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint_Successive_path()
- * @model
+ * @model containment="true" required="true" ordered="false"
* @generated
*/
- EList<FunctionPrototype> getSuccessive_path();
+ PrecedenceConstraint_precedingInstanceRef getPreceding();
/**
* Returns the value of the '<em><b>Preceding path</b></em>' reference list.
* The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
* <!-- begin-user-doc -->
- * <p>
- * If the meaning of the '<em>Preceding path</em>' reference list isn't clear, there really should be more of a description here...
- * </p>
* <!-- end-user-doc -->
- *
- * @return the value of the '<em>Preceding path</em>' reference list.
- * @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint_Preceding_path()
- * @model
+ * @param value the new value of the '<em>Preceding</em>' containment reference.
+ * @see #getPreceding()
* @generated
*/
- EList<FunctionPrototype> getPreceding_path();
+ void setPreceding(PrecedenceConstraint_precedingInstanceRef value);
/**
* Returns the value of the '<em><b>Successive</b></em>' reference list.
* The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * <!-- begin-model-doc -->
- * The function prototypes that must be executed after preceding was executed.
- * {derived from UML::DirectedRelationship::target}
- * <!-- end-model-doc -->
- *
- * @return the value of the '<em>Successive</em>' reference list.
+ * @return the value of the '<em>Successive</em>' containment reference list.
* @see org.eclipse.papyrus.eastadl.timing.TimingPackage#getPrecedenceConstraint_Successive()
- * @model required="true" transient="true" changeable="false" volatile="true" derived="true"
+ * @model containment="true" required="true" ordered="false"
* @generated
*/
- EList<FunctionPrototype> getSuccessive();
+ EList<PrecedenceConstraint_successiveInstanceRef> getSuccessive();
} // PrecedenceConstraint

Back to the top
@@ -16,143 +16,60 @@
/**
- * Returns the value of the '<em><b>Preceding path</b></em>' reference list.
- * The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
+ * Sets the value of the '{@link org.eclipse.papyrus.eastadl.timing.PrecedenceConstraint#getPreceding <em>Preceding</em>}' containment reference.
* <!-- begin-user-doc -->
@@ -16,143 +16,60 @@
/**
- * Returns the value of the '<em><b>Successive</b></em>' reference list.
- * The list contents are of type {@link org.eclipse.papyrus.eastadl.structure.functionmodeling.FunctionPrototype}.
+ * Returns the value of the '<em><b>Successive</b></em>' containment reference list.
+ * The list contents are of type {@link org.eclipse.papyrus.eastadl.infrastructure.PrecedenceConstraint_successiveInstanceRef}.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->